summaryrefslogtreecommitdiffstats
path: root/sys/net/if_var.h
diff options
context:
space:
mode:
Diffstat (limited to 'sys/net/if_var.h')
-rw-r--r--sys/net/if_var.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/sys/net/if_var.h b/sys/net/if_var.h
index b3ecb7d..2dcb6f9 100644
--- a/sys/net/if_var.h
+++ b/sys/net/if_var.h
@@ -195,17 +195,18 @@ struct ifnet {
/* protected by if_addr_mtx */
void *if_pf_kif;
void *if_lagg; /* lagg glue */
- u_char if_alloctype; /* if_type at time of allocation */
+ char *if_description; /* interface description */
+ u_int if_fib; /* interface FIB */
+ u_char if_alloctype; /* if_type at time of allocation */
/*
* Spare fields are added so that we can modify sensitive data
* structures without changing the kernel binary interface, and must
* be used with care where binary compatibility is required.
*/
- char if_cspare[3];
- char *if_description; /* interface description */
- void *if_pspare[7];
+ char if_cspare[3];
int if_ispare[4];
+ void *if_pspare[8]; /* 1 netmap, 7 TDB */
};
typedef void if_init_f_t(void *);
OpenPOWER on IntegriCloud